pub struct JoinEdge {
pub lhs_table: TableId,
pub rhs_table: TableId,
pub lhs_join_col: ColId,
pub rhs_join_col: ColId,
pub rhs_col: ColId,
}Expand description
A join edge is used for pruning queries when evaluating subscription updates.
If we have the following subscriptions:
SELECT a.* FROM a JOIN b ON a.id = b.id WHERE b.x = 1
SELECT a.* FROM a JOIN b ON a.id = b.id WHERE b.x = 2
...
SELECT a.* FROM a JOIN b ON a.id = b.id WHERE b.x = nWhenever a is updated, only the relevant queries are evaluated.
Fields
lhs_table: TableIdThe TableId for a
rhs_table: TableIdThe TableId for b
lhs_join_col: ColIdThe ColId for a.id
rhs_join_col: ColIdThe ColId for b.id
rhs_col: ColIdThe ColId for b.x
Implementations
Sourceimpl JoinEdge
impl JoinEdge
Sourcepub fn range_for_table(lhs_table: TableId) -> impl RangeBounds<Self>
pub fn range_for_table(lhs_table: TableId) -> impl RangeBounds<Self>
A helper method for finding a range of join edges for a particular table in a sorted set.