SubscriptionPlan

Struct SubscriptionPlan 

pub struct SubscriptionPlan { /* private fields */ }
A subscription defines a view over a table

Implementations

Source

impl SubscriptionPlan

pub fn is_join(&self) -> bool

Is this a plan for a join?

pub fn subscribed_table_id(&self) -> TableId

To which table does this plan subscribe?

pub fn subscribed_table_name(&self) -> &TableName

To which table does this plan subscribe?

pub fn table_ids(&self) -> impl Iterator<Item = TableId> + '_

From which tables does this plan read?

pub fn optimized_physical_plan(&self) -> &ProjectPlan

The optimized plan without any delta scans

pub fn index_ids(&self) -> impl Iterator<Item = (TableId, IndexId)>

From which indexes does this plan read?

pub fn for_each_insert<'a, Tx: Datastore + DeltaStore>( &self, tx: &'a Tx, metrics: &mut ExecutionMetrics, f: &mut dyn FnMut(Row<'a>) -> Result<()>, ) -> Result<()>

A subscription is just a view of a particular table. Here we compute the rows that are to be inserted into that view, and evaluate a closure over each one.

pub fn for_each_delete<'a, Tx: Datastore + DeltaStore>( &self, tx: &'a Tx, metrics: &mut ExecutionMetrics, f: &mut dyn FnMut(Row<'a>) -> Result<()>, ) -> Result<()>

A subscription is just a view of a particular table. Here we compute the rows that are to be removed from that view, and evaluate a closure over each one.

pub fn join_edge(&self) -> Option<(JoinEdge, AlgebraicValue)>

Returns a join edge for this query if it has one.

Requirements include:

  1. Unique join index
  2. Single column index lookup on the rhs table
  3. No self joins
pub fn compile( sql: &str, tx: &impl SchemaView, auth: &AuthCtx, ) -> Result<(Vec<Self>, bool)>

Generate a plan for incrementally maintaining a subscription